==> open-cluster-management-operator-model-6.1.0-sources.jar: io/fabric8/openclustermanagement/api/model/operator/v1/KlusterletSpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface KlusterletSpecFluent<A extends KlusterletSpecFluent<A>> extends Fluent<A>{
  public String getClusterName();
  public A withClusterName(String clusterName);
  public Boolean hasClusterName();
  public A addToExternalServerURLs(Integer index,ServerURL item);
  public A setToExternalServerURLs(Integer index,ServerURL item);
  public A addToExternalServerURLs(io.fabric8.openclustermanagement.api.model.operator.v1.ServerURL... items);
  public A addAllToExternalServerURLs(Collection<ServerURL> items);
  public A removeFromExternalServerURLs(io.fabric8.openclustermanagement.api.model.operator.v1.ServerURL... items);
  public A removeAllFromExternalServerURLs(Collection<ServerURL> items);
  public A removeMatchingFromExternalServerURLs(Predicate<ServerURLBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildExternalServerURLs instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ServerURL> getExternalServerURLs();
  public List<ServerURL> buildExternalServerURLs();
  public ServerURL buildExternalServerURL(Integer index);
  public ServerURL buildFirstExternalServerURL();
  public ServerURL buildLastExternalServerURL();
  public ServerURL buildMatchingExternalServerURL(Predicate<ServerURLBuilder> predicate);
  public Boolean hasMatchingExternalServerURL(Predicate<ServerURLBuilder> predicate);
  public A withExternalServerURLs(List<ServerURL> externalServerURLs);
  public A withExternalServerURLs(io.fabric8.openclustermanagement.api.model.operator.v1.ServerURL... externalServerURLs);
  public Boolean hasExternalServerURLs();
  public A addNewExternalServerURL(String caBundle,String url);
  public KlusterletSpecFluent.ExternalServerURLsNested<A> addNewExternalServerURL();
  public KlusterletSpecFluent.ExternalServerURLsNested<A> addNewExternalServerURLLike(ServerURL item);
  public KlusterletSpecFluent.ExternalServerURLsNested<A> setNewExternalServerURLLike(Integer index,ServerURL item);
  public KlusterletSpecFluent.ExternalServerURLsNested<A> editExternalServerURL(Integer index);
  public KlusterletSpecFluent.ExternalServerURLsNested<A> editFirstExternalServerURL();
  public KlusterletSpecFluent.ExternalServerURLsNested<A> editLastExternalServerURL();
  public KlusterletSpecFluent.ExternalServerURLsNested<A> editMatchingExternalServerURL(Predicate<ServerURLBuilder> predicate);
  public String getNamespace();
  public A withNamespace(String namespace);
  public Boolean hasNamespace();
  
  /**
   * This method has been deprecated, please use method buildNodePlacement instead.
   * @return The buildable object.
   */
  @Deprecated
  public NodePlacement getNodePlacement();
  public NodePlacement buildNodePlacement();
  public A withNodePlacement(NodePlacement nodePlacement);
  public Boolean hasNodePlacement();
  public KlusterletSpecFluent.NodePlacementNested<A> withNewNodePlacement();
  public KlusterletSpecFluent.NodePlacementNested<A> withNewNodePlacementLike(NodePlacement item);
  public KlusterletSpecFluent.NodePlacementNested<A> editNodePlacement();
  public KlusterletSpecFluent.NodePlacementNested<A> editOrNewNodePlacement();
  public KlusterletSpecFluent.NodePlacementNested<A> editOrNewNodePlacementLike(NodePlacement item);
  public String getRegistrationImagePullSpec();
  public A withRegistrationImagePullSpec(String registrationImagePullSpec);
  public Boolean hasRegistrationImagePullSpec();
  public String getWorkImagePullSpec();
  public A withWorkImagePullSpec(String workImagePullSpec);
  public Boolean hasWorkImagePullSpec();
  public interface ExternalServerURLsNested<N> extends Nested<N>,ServerURLFluent<KlusterletSpecFluent.ExternalServerURLsNested<N>>{
    public N and();
    public N endExternalServerURL();
    
  }
  public interface NodePlacementNested<N> extends Nested<N>,NodePlacementFluent<KlusterletSpecFluent.NodePlacementNested<N>>{
    public N and();
    public N endNodePlacement();
    
  }
  
}

==> open-cluster-management-operator-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/operator/v1/KlusterletSpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface KlusterletSpecFluent<A extends KlusterletSpecFluent<A>> extends Fluent<A>{
  public String getClusterName();
  public A withClusterName(String clusterName);
  public Boolean hasClusterName();
  public A addToExternalServerURLs(int index,ServerURL item);
  public A setToExternalServerURLs(int index,ServerURL item);
  public A addToExternalServerURLs(io.fabric8.openclustermanagement.api.model.operator.v1.ServerURL... items);
  public A addAllToExternalServerURLs(Collection<ServerURL> items);
  public A removeFromExternalServerURLs(io.fabric8.openclustermanagement.api.model.operator.v1.ServerURL... items);
  public A removeAllFromExternalServerURLs(Collection<ServerURL> items);
  public A removeMatchingFromExternalServerURLs(Predicate<ServerURLBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildExternalServerURLs instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ServerURL> getExternalServerURLs();
  public List<ServerURL> buildExternalServerURLs();
  public ServerURL buildExternalServerURL(int index);
  public ServerURL buildFirstExternalServerURL();
  public ServerURL buildLastExternalServerURL();
  public ServerURL buildMatchingExternalServerURL(Predicate<ServerURLBuilder> predicate);
  public Boolean hasMatchingExternalServerURL(Predicate<ServerURLBuilder> predicate);
  public A withExternalServerURLs(List<ServerURL> externalServerURLs);
  public A withExternalServerURLs(io.fabric8.openclustermanagement.api.model.operator.v1.ServerURL... externalServerURLs);
  public Boolean hasExternalServerURLs();
  public A addNewExternalServerURL(String caBundle,String url);
  public KlusterletSpecFluent.ExternalServerURLsNested<A> addNewExternalServerURL();
  public KlusterletSpecFluent.ExternalServerURLsNested<A> addNewExternalServerURLLike(ServerURL item);
  public KlusterletSpecFluent.ExternalServerURLsNested<A> setNewExternalServerURLLike(int index,ServerURL item);
  public KlusterletSpecFluent.ExternalServerURLsNested<A> editExternalServerURL(int index);
  public KlusterletSpecFluent.ExternalServerURLsNested<A> editFirstExternalServerURL();
  public KlusterletSpecFluent.ExternalServerURLsNested<A> editLastExternalServerURL();
  public KlusterletSpecFluent.ExternalServerURLsNested<A> editMatchingExternalServerURL(Predicate<ServerURLBuilder> predicate);
  public String getNamespace();
  public A withNamespace(String namespace);
  public Boolean hasNamespace();
  
  /**
   * This method has been deprecated, please use method buildNodePlacement instead.
   * @return The buildable object.
   */
  @Deprecated
  public NodePlacement getNodePlacement();
  public NodePlacement buildNodePlacement();
  public A withNodePlacement(NodePlacement nodePlacement);
  public Boolean hasNodePlacement();
  public KlusterletSpecFluent.NodePlacementNested<A> withNewNodePlacement();
  public KlusterletSpecFluent.NodePlacementNested<A> withNewNodePlacementLike(NodePlacement item);
  public KlusterletSpecFluent.NodePlacementNested<A> editNodePlacement();
  public KlusterletSpecFluent.NodePlacementNested<A> editOrNewNodePlacement();
  public KlusterletSpecFluent.NodePlacementNested<A> editOrNewNodePlacementLike(NodePlacement item);
  public String getRegistrationImagePullSpec();
  public A withRegistrationImagePullSpec(String registrationImagePullSpec);
  public Boolean hasRegistrationImagePullSpec();
  public String getWorkImagePullSpec();
  public A withWorkImagePullSpec(String workImagePullSpec);
  public Boolean hasWorkImagePullSpec();
  public interface ExternalServerURLsNested<N> extends Nested<N>,ServerURLFluent<KlusterletSpecFluent.ExternalServerURLsNested<N>>{
    public N and();
    public N endExternalServerURL();
    
  }
  public interface NodePlacementNested<N> extends Nested<N>,NodePlacementFluent<KlusterletSpecFluent.NodePlacementNested<N>>{
    public N and();
    public N endNodePlacement();
    
  }
  
}
